define((()=>(()=>{var e={758:(e,t,n)=>{n.p=document.querySelector("body").getAttribute("data-base-url")+"nbextensions/ailab-lite",window.require&&window.require.config({map:{"*":{"ailab-lite":"nbextensions/ailab-lite/index"}}}),e.exports={load_ipython_extension:function(){}}}},t={};function n(i){if(t[i])return t[i].exports;var r=t[i]={exports:{}};return e[i](r,r.exports,n),r.exports}return n.p="",n(758)})()));